Struct acme2::OrderBuilder [−][src]
pub struct OrderBuilder { /* fields omitted */ }A builder used to create a new Order.
Implementations
impl OrderBuilder[src]
impl OrderBuilder[src]pub fn new(account: Arc<Account>) -> Self[src]
pub fn set_identifiers(&mut self, identifiers: Vec<Identifier>) -> &mut Self[src]
Set the identifiers for an order.
In most cases, you can use OrderBuilder::add_dns_identifier
pub fn add_dns_identifier(&mut self, fqdn: String) -> &mut Self[src]
Add a type dns identifier to the list of identifiers for this
order.
pub async fn build(&mut self) -> Result<Order, Error>[src]
This will request a new Order from the ACME server.